@@ -10,6 +10,7 @@ from abaqus import mdb
 from abaqusConstants import STANDARD_EXPLICIT
 from abml import abml_helpers
 import interaction
+from abaqus import openMdb
 
 
 class Abml_Registry:
@@ -27,8 +28,18 @@ class Abml_Registry:
 @Abml_Registry.register("cae")
 class Abml_Cae:
     def __init__(self, models, **kwargs):
+        self.kwargs = kwargs
+
+        cae_path = self.kwargs.get("cae", None)
+        cae_path = models.pop("cae") if "cae" in models else None
+        if cae_path is not None:
+            self.open_cae(cae_path)
+
         self.models = to_object_key_mode(models["models"], type_="models")
 
+    def open_cae(self, path):
+        openMdb(pathName=path)
+
     def save_cae(self, filename):
         mdb.saveAs(pathName=filename)
 
@@ -109,6 +120,7 @@ class Abml_Model:
 
     def __init__(self, name, **kwargs):
         self.name = name
+
         self.create()
         self.m, self.a, self.p = abml_helpers.get_objects(self.name)
         self.kwargs = kwargs
@@ -127,7 +139,6 @@ class Abml_Model:
         self.sketches = {}
 
         self.create_instances(**kwargs)
-        self.create_modules(**kwargs)
 
     def create_instances(self, **kwargs):
         create_order = [
@@ -143,11 +154,26 @@ class Abml_Model:
             self.create_bcs,
             self.create_loads,
             self.create_jobs,
+            self.create_modules,
         ]
 
         for creation in create_order:
             creation(**kwargs)
 
+    def update_nested_dict(self, nested_dict, update_dict):
+        """
+        Recursively update a nested dictionary with a dictionary of key-value pairs
+        if the keys are not already present.
+        """
+        for k, v in update_dict.iteritems():
+            if isinstance(v, dict):
+                # Recursively update nested dictionaries
+                nested_dict[k] = self.update_nested_dict(nested_dict.get(k, {}), v)
+            elif k not in nested_dict:
+                # Key is not present, update the dictionary
+                nested_dict[k] = v
+        return nested_dict
+
     def create_sketches(self, **kwargs):
         sketches_list = [value for key, value in kwargs.items() if "sketches" in key]
         for sketches in sketches_list:
@@ -200,16 +226,14 @@ class Abml_Model:
         for interaction_props in interaction_props_list:
             if interaction_props is not None:
                 interaction_props = OrderedDict(sorted(interaction_props.items()))
-                self.interaction_props.update(
-                    to_object_key_mode(interaction_props, "interaction_properties", model=self)
-                )
+                self.interaction_props.update(to_object_key_mode(interaction_props, "interaction_props", model=self))
 
     def create_interactions(self, **kwargs):
         interactions_list = [value for key, value in kwargs.items() if "interactions" in key]
         for interactions in interactions_list:
             if interactions is not None:
                 interactions = OrderedDict(sorted(interactions.items()))
-                self.interactions.udpate(to_object_key_mode(interactions, "interactions", model=self))
+                self.interactions.update(to_object_key_mode(interactions, "interactions", model=self))
 
     def create_constraints(self, **kwargs):
         constraints_list = [value for key, value in kwargs.items() if "constraints" in key]
@@ -240,15 +264,23 @@ class Abml_Model:
                 self.jobs.update(to_object_key_mode(jobs, "jobs", model=self))
 
     def create_modules(self, **kwargs):
-        modules_list = [value for key, value in kwargs.items() if "modules" in key]
         modules_list = kwargs.get("modules", [])
+        # abml_helpers.cprint("############## {}".format(modules_list[0]))
+        modules_list = [value for key, value in kwargs.items() if "modules" in key]
+        # abml_helpers.cprint(modules_list[0])
         for modules in modules_list:
             if modules is not None:
-                modules = OrderedDict(sorted(modules.items()))
-                self.modules = self.create_instances(**modules)
+                if isinstance(modules, dict):
+                    modules = OrderedDict(sorted(modules.items()))
+                    self.create_instances(**modules)
+                elif isinstance(modules, list):
+                    for module in modules:
+                        module = OrderedDict(sorted(module.items()))
+                        self.create_instances(**module)
 
     def create(self):
-        mdb.Model(modelType=STANDARD_EXPLICIT, name=self.name)
+        if self.name not in mdb.models.keys():
+            mdb.Model(modelType=STANDARD_EXPLICIT, name=self.name)
 
         if "Model-1" in mdb.models.keys():
             del mdb.models["Model-1"]
@@ -458,17 +490,6 @@ def to_object_hierachy_mode(data, type_, **kwargs):
     parameter specifies the name of the class to create the object from, and must be a string that matches the
     name of a class registered with the `Abml_Registry.registry` dictionary.
 
-    Examples
-    --------
-    **python
-    >>> data = {'name': 'Alice', 'age': 25, 'address': {'street': '123 Main St', 'city': 'Anytown'}}
-    >>> obj = to_object_hierarchy_mode(data, 'Person', occupation='Engineer')
-    >>> obj.name
-    'Alice'
-    >>> obj.address.city
-    'Anytown'
-    >>> obj.occupation
-    'Engineer'
     """
     data.update(kwargs)
     object_ = Abml_Registry.registry[type_](**data)
