@@ -39,14 +39,20 @@ class Abml_Job:
 
         if self.kwargs.get("write_input", False):
             self.write_input()
-            self.add_to_header(subroutine="{}.inp".format(self.name), priority=self.kwargs.get("priority", "default"))
+            self.add_to_header(subroutine=self.sub_name, priority=self.kwargs.get("priority", "default"))
 
     def write_input(self):
         mdb.jobs[self.name].writeInput(consistencyChecking=OFF)
 
+    def load_subname(self):
+        if "subroutine_queue" in self.kwargs:
+            self.sub_name = self.kwargs["subroutine_queue"]
+        else:
+            self.sub_name = "{}.for".format(self.name)
+
     def write_and_copy_input_to_path(self, path):
         self.write_input()
-        self.add_to_header(subroutine="{}.inp".format(self.name), priority=self.kwargs.get("priority", "default"))
+        self.add_to_header(subroutine="{}.for".format(self.name), priority=self.kwargs.get("priority", "default"))
         filename = "{}.inp".format(self.name)
         copy(filename, os.path.join(path, filename))
 
