@@ -64,6 +64,9 @@ class Abml_Part:
         self.name = name
         self.create()
 
+        if self.name in model.parts:
+            self.inherit(model.parts[self.name])
+
         geometry = kwargs.get("geometry")
         if geometry is not None:
             params = {
@@ -99,6 +102,7 @@ class Abml_Part:
                 "part": self,
             }
             self.surfaces = to_object_key_mode(**params)
+            # to_object_key_mode(**params)
 
         sets = kwargs.get("sets")
 
@@ -130,8 +134,15 @@ class Abml_Part:
             self.mesh = to_object_cmd_mode(**params)
             self.generate_mesh()
 
+    def inherit(self, other):
+        if isinstance(other, Abml_Part):
+            for attr in dir(other):
+                if not attr.startswith("__") and not callable(getattr(other, attr)):
+                    setattr(self, attr, getattr(other, attr))
+
     def create(self):
-        self.model.m.Part(dimensionality=THREE_D, name=self.name, type=DEFORMABLE_BODY)
+        if self.name not in self.model.parts.keys():
+            self.model.m.Part(dimensionality=THREE_D, name=self.name, type=DEFORMABLE_BODY)
 
     def get_sequence_from_set_list(self, set_list):
         face_seq = None
@@ -525,16 +536,25 @@ class Abml_Surface(Abml_Helpers):
     def create(self):
         part = self.model.p[self.part.name]
 
-        face_seq = self.part.geometry.get_sequence_from_list(self.faces, "face")
+        try:
+            face_seq = self.part.geometry.get_sequence_from_list(self.faces, "face")
+        except AttributeError:
+            face_seq = self.part.model.parts[self.part.name].geometry.get_sequence_from_list(self.faces, "face")
 
         try:
             part.Surface(side1Faces=face_seq, name=self.name)
         except Exception as e:
             error_msg = """
             surface_name: {name}
+            faces_inp: {faces}
+            face_seq: {face_seq}
+            part: {part}
             {e}
             """.format(
                 name=self.name,
+                faces=self.faces,
+                face_seq=face_seq,
+                part=self.part.name,
                 e=e,
             )
             raise ValueError(error_msg)
